@@ -186,6 +186,10 @@ CtkDisplayInit(interp, dispPtr, termName)
     char *type;
     int length;
     FILE *outPtr;
+
+    int fd;			/* For the return value of Tcl_GetChannelHandle */
+    /* The Tcl_File is no longer needed, since Channels now subsume their work */
+
     static int initialized = 0;
 
     if (!initialized) {
@@ -219,15 +223,27 @@ CtkDisplayInit(interp, dispPtr, termName)
     dispPtr->name[length] = '\0';
 
     if (strcmp(dispPtr->name, "tty") == 0) {
-	dispPtr->fd = 0;
+	dispPtr->chan = Tcl_GetStdChannel(TCL_STDIN);
     } else {
-	dispPtr->fd = HAVE_SET_TERM ? open(dispPtr->name, O_RDWR, 0) : -1;
-	if (dispPtr->fd == -1) {
+#ifdef HAVE_SET_TERM
+	dispPtr->chan = HAVE_SET_TERM ? Tcl_OpenFileChannel(interp, dispPtr->name, 
+							    "r+", 0) : NULL;
+#else
+	dispPtr->chan = NULL;
+#endif
+        if (dispPtr->chan == NULL) {
 	    Tcl_AppendResult(interp, "couldn't connect to device \"",
 		    dispPtr->name, "\"", (char *) NULL);
 	    goto error;
 	}
     }
+    if ( Tcl_GetChannelHandle(dispPtr->chan, TCL_READABLE, &(dispPtr->fd) ) != TCL_OK )
+    {
+    	Tcl_AppendResult(interp, "couldn't get device handle for device \"",
+    		dispPtr->name, "\"", (char *) NULL);
+        goto error;
+    }
+    
     if (!isatty(dispPtr->fd)) {
 	Tcl_AppendResult(interp, "display device \"", dispPtr->name,
 		"\" is not a tty", (char *) NULL);
@@ -249,7 +265,7 @@ CtkDisplayInit(interp, dispPtr, termName)
     noecho();
     keypad(stdscr, TRUE);
 
-    Tk_CreateFileHandler(dispPtr->fd, TK_READABLE,
+    Tcl_CreateChannelHandler(dispPtr->chan, TCL_READABLE,
     	    TermFileProc, (ClientData) dispPtr);
     return TCL_OK;
 
@@ -285,7 +301,8 @@ CtkDisplayEnd(dispPtr)
     curs_set(1);
     endwin();
 
-    Tk_DeleteFileHandler(dispPtr->fd);
+    Tcl_DeleteChannelHandler(dispPtr->chan,
+		TermFileProc, (ClientData) dispPtr);
     if (dispPtr->inPtr != stdin) {
     	fclose(dispPtr->inPtr);
     }
@@ -471,7 +488,7 @@ Ctk_DisplayHeight(dispPtr)
  *
  * Results:
  *	Returns TK_FILE_HANDLED if any events were processed.
- *	Otherwise returns TK_READABLE.
+ *	Otherwise returns TCL_READABLE.
  *
  * Side effects:
  *	Dispatches events (invoking event handlers).
@@ -491,7 +508,7 @@ TermFileProc(clientData, mask)
     KeyCodeInfo *codePtr;
     int key;
 
-    if (mask & TK_READABLE) {
+    if ((mask & TCL_READABLE) == TCL_READABLE) {
 	SetDisplay(dispPtr);
 
 	key = getch();
