@@ -272,7 +272,7 @@ Tk_EntryCmd(clientData, interp, argc, argv)
 	goto error;
     }
 
-    interp->result = Tk_PathName(entryPtr->tkwin);
+    Tcl_SetResult(interp,Tk_PathName(entryPtr->tkwin), TCL_VOLATILE);
     return TCL_OK;
 
     error:
@@ -368,7 +368,7 @@ EntryWidgetCmd(clientData, interp, argc, argv)
 		    argv[0], " get\"", (char *) NULL);
 	    goto error;
 	}
-	interp->result = entryPtr->string;
+	Tcl_SetResult(interp,entryPtr->string,TCL_VOLATILE);
     } else if ((c == 'i') && (strncmp(argv[1], "icursor", length) == 0)
 	    && (length >= 2)) {
 	if (argc != 3) {
@@ -394,7 +394,11 @@ EntryWidgetCmd(clientData, interp, argc, argv)
 	if (GetEntryIndex(interp, entryPtr, argv[2], &index) != TCL_OK) {
 	    goto error;
 	}
-	sprintf(interp->result, "%d", index);
+	{
+          char buffer[20];
+	  sprintf(buffer, "%d", index);
+	  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+	}
     } else if ((c == 'i') && (strncmp(argv[1], "insert", length) == 0)
 	    && (length >= 3)) {
 	int index;
@@ -443,9 +447,9 @@ EntryWidgetCmd(clientData, interp, argc, argv)
 		goto error;
 	    }
 	    if (entryPtr->selectFirst == -1) {
-		interp->result = "0";
+		Tcl_SetResult(interp,"0",TCL_STATIC);
 	    } else {
-		interp->result = "1";
+		Tcl_SetResult(interp,"1",TCL_STATIC);
 	    }
 	    goto done;
 	}
@@ -522,8 +526,10 @@ EntryWidgetCmd(clientData, interp, argc, argv)
 	double fraction, first, last;
 
 	if (argc == 2) {
+	    char buffer[40];
 	    EntryVisibleRange(entryPtr, &first, &last);
-	    sprintf(interp->result, "%g %g", first, last);
+	    sprintf(buffer, "%g %g", first, last);
+	    Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 	    goto done;
 	} else if (argc == 3) {
 	    if (GetEntryIndex(interp, entryPtr, argv[2], &index) != TCL_OK) {
@@ -1245,7 +1251,7 @@ EntryEventProc(clientData, eventPtr)
 		    Tcl_GetCommandName(entryPtr->interp, entryPtr->widgetCmd));
 	}
 	if (entryPtr->flags & REDRAW_PENDING) {
-	    Tk_CancelIdleCall(DisplayEntry, (ClientData) entryPtr);
+	    Tcl_CancelIdleCall(DisplayEntry, (ClientData) entryPtr);
 	}
 	Tk_EventuallyFree((ClientData) entryPtr, DestroyEntry);
     } else if (eventPtr->type == CTK_MAP_EVENT) {
@@ -1363,7 +1369,7 @@ GetEntryIndex(interp, entryPtr, string, indexPtr)
 	}
     } else if (string[0] == 's') {
 	if (entryPtr->selectFirst == -1) {
-	    interp->result = "selection isn't in entry";
+	    Tcl_SetResult(interp,"selection isn't in entry",TCL_STATIC);
 	    return TCL_ERROR;
 	}
 	if (length < 5) {
@@ -1510,7 +1516,7 @@ EventuallyRedraw(entryPtr)
 
     if (!(entryPtr->flags & REDRAW_PENDING)) {
 	entryPtr->flags |= REDRAW_PENDING;
-	Tk_DoWhenIdle(DisplayEntry, (ClientData) entryPtr);
+	Tcl_DoWhenIdle(DisplayEntry, (ClientData) entryPtr);
     }
 }
 
@@ -1603,7 +1609,7 @@ EntryUpdateScrollbar(entryPtr)
     if (code != TCL_OK) {
 	Tcl_AddErrorInfo(entryPtr->interp,
 		"\n    (horizontal scrolling command executed by entry)");
-	Tk_BackgroundError(entryPtr->interp);
+	Tcl_BackgroundError(entryPtr->interp);
     }
     Tcl_SetResult(entryPtr->interp, (char *) NULL, TCL_STATIC);
 }
