@@ -71,7 +71,7 @@ Tk_FocusCmd(clientData, interp, argc, argv)
     if (argc == 1) {
 	focusWinPtr = TkGetFocus(winPtr);
 	if (focusWinPtr != NULL) {
-	    interp->result = focusWinPtr->pathName;
+	    Tcl_SetResult(interp,focusWinPtr->pathName,TCL_VOLATILE);
 	}
 	return TCL_OK;
     }
@@ -111,7 +111,7 @@ Tk_FocusCmd(clientData, interp, argc, argv)
 	}
 	newPtr = TkGetFocus(newPtr);
 	if (newPtr != NULL) {
-	    interp->result = newPtr->pathName;
+	    Tcl_SetResult(interp,newPtr->pathName,TCL_VOLATILE);
 	}
     } else if ((c == 'f') && (strncmp(argv[1], "-force", length) == 0)) {
 	if (argc != 3) {
@@ -140,7 +140,7 @@ Tk_FocusCmd(clientData, interp, argc, argv)
 	topLevelPtr = Ctk_TopLevel(newPtr);
 	hPtr = Tcl_FindHashEntry(&focusTable, (char *) topLevelPtr);
 	if (hPtr && (newPtr = (TkWindow *) Tcl_GetHashValue(hPtr))) {
-	    interp->result = topLevelPtr->pathName;
+	    Tcl_SetResult(interp,topLevelPtr->pathName,TCL_VOLATILE);
 	}
     } else {
 	Tcl_AppendResult(interp, "bad option \"", argv[1],
