@@ -148,8 +148,10 @@ extern int errno;
  * Tcl versions retry automatically if interrupted by signals.
  */
 
+#ifdef OLDTCL
 #define open(a,b,c) TclOpen(a,b,c)
 #define read(a,b,c) TclRead(a,b,c)
+#endif
 #define waitpid(a,b,c) TclWaitpid(a,b,c)
 #define write(a,b,c) TclWrite(a,b,c)
 EXTERN int	TclOpen _ANSI_ARGS_((char *path, int oflag, mode_t mode));
@@ -178,6 +180,6 @@ EXTERN int            gettimeofday _ANSI_ARGS_((struct timeval *tp,
  * in any other header file.
  */
 
-extern void		panic();
+//extern void		panic();
 
 #endif /* _TKPORT */
