@@ -73,7 +73,6 @@ static TkCmd commands[] = {
      * Commands that are part of the intrinsics:
      */
 
-    {"after",		Tk_AfterCmd},
     {"bell",		Tk_BellCmd},
     {"bind",		Tk_BindCmd},
     {"bindtags",	Tk_BindtagsCmd},
@@ -82,7 +81,6 @@ static TkCmd commands[] = {
     {"ctk_event",	Ctk_CtkEventCmd},
     {"destroy",		Tk_DestroyCmd},
     {"exit",		Tk_ExitCmd},
-    {"fileevent",		Tk_FileeventCmd},
     {"focus",		Tk_FocusCmd},
     /* {"grab",		Tk_GrabCmd}, */
     /* {"image",		Tk_ImageCmd}, */
@@ -170,6 +168,9 @@ int
 Tk_Init(interp)
     Tcl_Interp *interp;		/* Interpreter to initialize. */
 {
+#ifdef USE_TCL_STUBS
+    Tk_Window winPtr;
+#endif
     static char initCmd[] =
 	"if [file exists $tk_library/ctk.tcl] {\n\
 	    source $tk_library/ctk.tcl\n\
@@ -179,8 +180,25 @@ Tk_Init(interp)
 	    append msg \"environment variable?\"\n\
 	    error $msg\n\
 	}";
+    int retval;
 
-    return Tcl_Eval(interp, initCmd);
+#ifdef USE_TCL_STUBS
+    winPtr = Tk_CreateMainWindow(interp, NULL, "ctk", "ctk");
+    if (winPtr == NULL) {
+        return(TCL_ERROR);
+    }
+#endif
+
+    retval = Tcl_Eval(interp, initCmd);
+    if (retval != TCL_OK) {
+        return(retval);
+    }
+
+#ifdef USE_TCL_STUBS
+    Tcl_SetMainLoop(Tk_MainLoop);
+#endif
+
+    return(retval);
 }
 
 /*
@@ -382,7 +400,6 @@ Tk_CreateMainWindow(interp, screenName, baseName, className)
 	Tcl_CreateCommand(interp, cmdPtr->name, cmdPtr->cmdProc,
 		(ClientData) winPtr, (void (*)()) NULL);
     }
-    Tcl_CallWhenDeleted(interp, TkEventCleanupProc, (ClientData) NULL);
 
     /*
      * Set variables for the intepreter.
@@ -1360,7 +1377,7 @@ Tk_MainWindow(interp)
 	    return (Tk_Window) mainPtr->winPtr;
 	}
     }
-    interp->result = "this isn't a Tk application";
+    Tcl_SetResult(interp,"this isn't a Tk application",TCL_STATIC);
     return NULL;
 }
 
